context("canvasXpress Web Charts - Radar")


test_that("cXradar1", {
    check_ui_test(cXradar1())
})

test_that("cXradar2", {
    check_ui_test(cXradar2())
})

test_that("cXradar3", {
    check_ui_test(cXradar3())
})

test_that("cXradar4", {
    check_ui_test(cXradar4())

    warning('Hover over any point - highlights middle circle point')
})

test_that("cXradar5", {
    check_ui_test(cXradar5())
})

test_that("cXradar6", {
    check_ui_test(cXradar6())
})

test_that("cXradar7", {
    check_ui_test(cXradar7())
})

test_that("cXradar8", {
    check_ui_test(cXradar8())
})
